==> nhc98src-1.18.tar.gz: nhc98-1.18/src/prelude/PreludeList/DropWhile.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define v170	((void*)startLabel+22)
#define v171	((void*)startLabel+32)
#define v172	((void*)startLabel+58)
#define v174	((void*)startLabel+68)
#define v167	((void*)startLabel+73)
#define CT_v182	((void*)startLabel+208)
#define FN_LAMBDA165	((void*)startLabel+260)
#define CT_v186	((void*)startLabel+304)
#define CF_LAMBDA165	((void*)startLabel+312)
#define ST_v177	((void*)startLabel+332)
#define PP_LAMBDA165	((void*)startLabel+350)
#define PC_LAMBDA165	((void*)startLabel+350)
#define ST_v184	((void*)startLabel+350)
#define ST_v185	((void*)startLabel+377)
#define PS_v181	((void*)startLabel+448)
#define PS_v179	((void*)startLabel+460)
#define PS_v176	((void*)startLabel+472)
#define PS_v180	((void*)startLabel+484)
#define PS_v183	((void*)startLabel+496)
extern Node CF_Prelude_46otherwise[];
extern Node FN_Prelude_46error[];
extern Node PM_Prelude[];
extern Node PC_Prelude_46error[];
extern Node PC_Prelude_46_91_93[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v182)
,};
Node FN_Prelude_46dropWhile[] = {
  bytes2word(NEEDSTACK_I16,PUSH_ARG_I2,EVAL,NEEDHEAP_I32)
, bytes2word(TABLESWITCH,2,TOP(4),BOT(4))
,	/* v170: (byte 2) */
  bytes2word(TOP(14),BOT(14),POP_I1,PUSH_HEAP)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CVAL_N1,12)
,	/* v171: (byte 4) */
  bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,RETURN)
, bytes2word(UNPACK,2,PUSH_P1,0)
, bytes2word(PUSH_ARG_I1,EVAL,NEEDHEAP_I32,APPLY)
, bytes2word(1,EVAL,NEEDHEAP_I32,JUMPFALSE)
, bytes2word(14,0,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(7,HEAP_CVAL_N1,17,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_ARG,1)
,	/* v172: (byte 2) */
  bytes2word(HEAP_I2,RETURN_EVAL,PUSH_CVAL_P1,8)
, bytes2word(ZAP_ARG_I1,EVAL,NEEDHEAP_I32,JUMPFALSE)
,	/* v174: (byte 4) */
  bytes2word(4,0,PUSH_ARG_I2,RETURN)
, bytes2word(POP_P1,2,JUMP,2)
,	/* v167: (byte 1) */
  bytes2word(0,HEAP_CVAL_P1,9,HEAP_CVAL_N1)
, bytes2word(22,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,10,HEAP_CVAL_N1)
, bytes2word(27,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,10,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v181)
, 0
, 0
, 0
, 0
, useLabel(PS_v180)
, 0
, 0
, 0
, 0
, useLabel(PS_v176)
, 0
, 0
, 0
, 0
, useLabel(PS_v179)
, 0
, 0
, 0
, 0
, CONSTR(0,0,0)
, 0
, 0
, 0
, 0
, 40001
, useLabel(ST_v177)
,	/* CT_v182: (byte 0) */
  HW(4,2)
, 0
,};
Node F0_Prelude_46dropWhile[] = {
  CAPTAG(useLabel(FN_Prelude_46dropWhile),2)
, useLabel(PS_v176)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_Prelude_46dropWhile))
, useLabel(CF_Prelude_46otherwise)
, VAPTAG(useLabel(FN_LAMBDA165))
, VAPTAG(useLabel(FN_Prelude_46error))
, bytes2word(0,0,0,0)
, useLabel(CT_v186)
,	/* FN_LAMBDA165: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,8,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, 0
, 0
, 0
, 0
, useLabel(ST_v185)
, 40001
, useLabel(ST_v184)
,	/* CT_v186: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA165: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA165))
, useLabel(PS_v183)
, 0
, 0
, 0
,};
Node PP_Prelude_46dropWhile[] = {
 };
Node PC_Prelude_46dropWhile[] = {
 	/* ST_v177: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(100,114,111,112)
, bytes2word(87,104,105,108)
,	/* PP_LAMBDA165: (byte 2) */
 	/* PC_LAMBDA165: (byte 2) */
 	/* ST_v184: (byte 2) */
  bytes2word(101,0,80,114)
, bytes2word(101,108,117,100)
, bytes2word(101,46,100,114)
, bytes2word(111,112,87,104)
, bytes2word(105,108,101,58)
, bytes2word(52,58,49,45)
, bytes2word(54,58,51,57)
,	/* ST_v185: (byte 1) */
  bytes2word(0,80,114,101)
, bytes2word(108,117,100,101)
, bytes2word(58,46,47,68)
, bytes2word(114,111,112,87)
, bytes2word(104,105,108,101)
, bytes2word(46,104,115,58)
, bytes2word(32,80,97,116)
, bytes2word(116,101,114,110)
, bytes2word(32,109,97,116)
, bytes2word(99,104,32,102)
, bytes2word(97,105,108,117)
, bytes2word(114,101,32,105)
, bytes2word(110,32,102,117)
, bytes2word(110,99,116,105)
, bytes2word(111,110,32,97)
, bytes2word(116,32,52,58)
, bytes2word(49,45,54,58)
, bytes2word(51,57,46,0)
,	/* PS_v181: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46dropWhile)
, useLabel(PC_Prelude_46error)
,	/* PS_v179: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46dropWhile)
, useLabel(PC_Prelude_46_91_93)
,	/* PS_v176: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46dropWhile)
, useLabel(PC_Prelude_46dropWhile)
,	/* PS_v180: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46dropWhile)
, useLabel(PC_LAMBDA165)
,	/* PS_v183: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_LAMBDA165)
, useLabel(PC_LAMBDA165)
,};

==> nhc98src-1.20.tar.gz: nhc98-1.20/src/prelude/PreludeList/DropWhile.p.c <==
#include "newmacros.h"
#include "runtime.h"

#define v175	((void*)startLabel+22)
#define v176	((void*)startLabel+32)
#define v177	((void*)startLabel+58)
#define v179	((void*)startLabel+68)
#define v172	((void*)startLabel+73)
#define CT_v187	((void*)startLabel+208)
#define FN_LAMBDA170	((void*)startLabel+260)
#define CT_v191	((void*)startLabel+304)
#define CF_LAMBDA170	((void*)startLabel+312)
#define ST_v182	((void*)startLabel+332)
#define PP_LAMBDA170	((void*)startLabel+350)
#define PC_LAMBDA170	((void*)startLabel+350)
#define ST_v189	((void*)startLabel+350)
#define ST_v190	((void*)startLabel+377)
#define PS_v186	((void*)startLabel+448)
#define PS_v184	((void*)startLabel+460)
#define PS_v181	((void*)startLabel+472)
#define PS_v185	((void*)startLabel+484)
#define PS_v188	((void*)startLabel+496)
extern Node CF_Prelude_46otherwise[];
extern Node FN_NHC_46Internal_46_95patternMatchFail[];
extern Node PM_Prelude[];
extern Node PC_NHC_46Internal_46_95patternMatchFail[];
extern Node PC_Prelude_46_91_93[];

static Node startLabel[] = {
  bytes2word(0,0,2,0)
, bytes2word(1,1,0,2)
, useLabel(CT_v187)
,};
Node FN_Prelude_46dropWhile[] = {
  bytes2word(NEEDSTACK_I16,PUSH_ARG_I2,EVAL,NEEDHEAP_I32)
, bytes2word(TABLESWITCH,2,TOP(4),BOT(4))
,	/* v175: (byte 2) */
  bytes2word(TOP(14),BOT(14),POP_I1,PUSH_HEAP)
, bytes2word(HEAP_CVAL_N1,7,HEAP_CVAL_N1,12)
,	/* v176: (byte 4) */
  bytes2word(HEAP_CREATE,HEAP_SPACE,HEAP_SPACE,RETURN)
, bytes2word(UNPACK,2,PUSH_P1,0)
, bytes2word(PUSH_ARG_I1,EVAL,NEEDHEAP_I32,APPLY)
, bytes2word(1,EVAL,NEEDHEAP_I32,JUMPFALSE)
, bytes2word(14,0,PUSH_HEAP,HEAP_CVAL_P1)
, bytes2word(7,HEAP_CVAL_N1,17,HEAP_CREATE)
, bytes2word(HEAP_SPACE,HEAP_SPACE,HEAP_ARG,1)
,	/* v177: (byte 2) */
  bytes2word(HEAP_I2,RETURN_EVAL,PUSH_CVAL_P1,8)
, bytes2word(ZAP_ARG_I1,EVAL,NEEDHEAP_I32,JUMPFALSE)
,	/* v179: (byte 4) */
  bytes2word(4,0,PUSH_ARG_I2,RETURN)
, bytes2word(POP_P1,2,JUMP,2)
,	/* v172: (byte 1) */
  bytes2word(0,HEAP_CVAL_P1,9,HEAP_CVAL_N1)
, bytes2word(22,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(PUSH_HEAP,HEAP_CVAL_P1,10,HEAP_CVAL_N1)
, bytes2word(27,HEAP_CREATE,HEAP_SPACE,HEAP_SPACE)
, bytes2word(HEAP_OFF_N1,10,RETURN_EVAL,ENDCODE)
, bytes2word(0,0,0,0)
, 0
, useLabel(PS_v186)
, 0
, 0
, 0
, 0
, useLabel(PS_v185)
, 0
, 0
, 0
, 0
, useLabel(PS_v181)
, 0
, 0
, 0
, 0
, useLabel(PS_v184)
, 0
, 0
, 0
, 0
, CONSTR(0,0,0)
, 0
, 0
, 0
, 0
, 40001
, useLabel(ST_v182)
,	/* CT_v187: (byte 0) */
  HW(4,2)
, 0
,};
Node F0_Prelude_46dropWhile[] = {
  CAPTAG(useLabel(FN_Prelude_46dropWhile),2)
, useLabel(PS_v181)
, 0
, 0
, 0
, VAPTAG(useLabel(FN_Prelude_46dropWhile))
, useLabel(CF_Prelude_46otherwise)
, VAPTAG(useLabel(FN_LAMBDA170))
, VAPTAG(useLabel(FN_NHC_46Internal_46_95patternMatchFail))
, bytes2word(0,0,0,0)
, useLabel(CT_v191)
,	/* FN_LAMBDA170: (byte 0) */
  bytes2word(NEEDHEAP_I32,PUSH_CADR_N1,8,STRING)
, bytes2word(RETURN,ENDCODE,0,0)
, bytes2word(0,0,0,0)
, CONSTRW(1,0)
, 0
, 0
, 0
, 0
, useLabel(ST_v190)
, 40001
, useLabel(ST_v189)
,	/* CT_v191: (byte 0) */
  HW(0,0)
, 0
,	/* CF_LAMBDA170: (byte 0) */
  VAPTAG(useLabel(FN_LAMBDA170))
, useLabel(PS_v188)
, 0
, 0
, 0
,};
Node PP_Prelude_46dropWhile[] = {
 };
Node PC_Prelude_46dropWhile[] = {
 	/* ST_v182: (byte 0) */
  bytes2word(80,114,101,108)
, bytes2word(117,100,101,46)
, bytes2word(100,114,111,112)
, bytes2word(87,104,105,108)
,	/* PP_LAMBDA170: (byte 2) */
 	/* PC_LAMBDA170: (byte 2) */
 	/* ST_v189: (byte 2) */
  bytes2word(101,0,80,114)
, bytes2word(101,108,117,100)
, bytes2word(101,46,100,114)
, bytes2word(111,112,87,104)
, bytes2word(105,108,101,58)
, bytes2word(52,58,49,45)
, bytes2word(54,58,51,57)
,	/* ST_v190: (byte 1) */
  bytes2word(0,80,114,101)
, bytes2word(108,117,100,101)
, bytes2word(58,46,47,68)
, bytes2word(114,111,112,87)
, bytes2word(104,105,108,101)
, bytes2word(46,104,115,58)
, bytes2word(32,80,97,116)
, bytes2word(116,101,114,110)
, bytes2word(32,109,97,116)
, bytes2word(99,104,32,102)
, bytes2word(97,105,108,117)
, bytes2word(114,101,32,105)
, bytes2word(110,32,102,117)
, bytes2word(110,99,116,105)
, bytes2word(111,110,32,97)
, bytes2word(116,32,52,58)
, bytes2word(49,45,54,58)
, bytes2word(51,57,46,0)
,	/* PS_v186: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46dropWhile)
, useLabel(PC_NHC_46Internal_46_95patternMatchFail)
,	/* PS_v184: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46dropWhile)
, useLabel(PC_Prelude_46_91_93)
,	/* PS_v181: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46dropWhile)
, useLabel(PC_Prelude_46dropWhile)
,	/* PS_v185: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_Prelude_46dropWhile)
, useLabel(PC_LAMBDA170)
,	/* PS_v188: (byte 0) */
  useLabel(PM_Prelude)
, useLabel(PP_LAMBDA170)
, useLabel(PC_LAMBDA170)
,};
